@@ -3,6 +3,8 @@
 #' Download the entire StudentLife dataset or
 #' a smaller sample dataset for testing.
 #'
+#' If \code{url = "rdata"} then data will be downloaded
+#' from <https://zenodo.org/record/3529253>
 #' If \code{url = "dartmouth"} then data will be downloaded
 #' from <https://studentlife.cs.dartmouth.edu/dataset/dataset.tar.bz2>
 #' If \code{url = "testdata"} then data will be downloaded
@@ -11,9 +13,11 @@
 #'
 #'
 #'@param url A character string. Either
-#'"dartmouth" for the Dartmouth URL, or
+#'"rdata" for the URL to the (more efficient)
+#'RData format version hosted on Zenodo, or
+#'"dartmouth" for the (original) Dartmouth URL, or
 #'"testdata" for a small sample dataset. Otherwise
-#'or a full URL of your choice can be specified leading to
+#'a full URL of your choice can be specified leading to
 #'the StudentLife dataset as a \code{.tar.gz} file.
 #'@param location The destination path. If the path does
 #'not exist it is created with \code{\link{dir.create}}
@@ -28,7 +32,7 @@
 #'d <- tempdir()
 #'download_studentlife(location = d, url = "testdata")
 #'
-#'\donttest{
+#'\dontrun{
 #'## With menu
 #'load_SL_tibble(location = d)
 #'}
@@ -44,49 +48,77 @@ download_studentlife <- function(
   unzip = TRUE,
   untar = TRUE) {
 
-  if (tolower(url) == "dartmouth")
+  zip <- FALSE
+  if (tolower(url) == "dartmouth") {
+
     url <- paste0("https://studentlife.cs.dartmouth.edu",
                   "/dataset/dataset.tar.bz2")
 
-  if (tolower(url) == "testdata") {
+    mes1 <- "Downloading the original StudentLife dataset..."
+    f <- "dataset.tar.bz2"
+
+  } else if (tolower(url) == "testdata") {
 
     url <- paste0("https://raw.githubusercontent.com/",
                   "frycast/studentlife/master/tests/",
                   "testthat/testdata/sample/sample_dataset.tar.bz2")
 
     mes1 <- "Downloading the small sample dataset..."
+    f <- "dataset.tar.bz2"
+
+  } else if (tolower(url) == "rdata") {
+
+    url <- paste0("https://zenodo.org/record/3529253/",
+                  "files/dataset_rds.zip?download=1")
+
+    mes1 <- "Downloading the RData studentlife dataset..."
+    f <- "dataset_rds.zip"
+    untar <- FALSE
+    zip <- TRUE
 
   } else {
 
-    mes1 <- "Downloading the StudentLife dataset..."
+    mes1 <- "Downloading from user specified url..."
+    f <- "dataset.tar.bz2"
+
   }
 
   message(mes1)
-  f <- "dataset.tar.bz2"
   p <- paste0(location, "/", f)
   if (!dir.exists(location)) dir.create(location)
-  utils::download.file(url = url, destfile = p, cacheOK = FALSE)
+  if (!zip) {utils::download.file(url = url, destfile = p, cacheOK = FALSE)}
+  if (zip) {utils::download.file(url = url, destfile = p, method = 'curl')}
   message("Download complete")
-  if (unzip) {
+
+  if (zip && unzip) {
+    message("Unzipping the dataset...")
+    utils::unzip(p, exdir = location)
+    message("Unzip complete")
+  } else if (unzip) {
     message("Unzipping the dataset...")
     R.utils::bunzip2(p, remove = FALSE, skip = TRUE)
-    message("Unzip complete")}
+    message("Unzip complete")
+  }
   if (untar) {
     f <- "dataset.tar"
     p <- paste0(location, "/", f)
     message("Untarring the dataset...")
     utils::untar(p, exdir = location)
-    message("Untar complete")}
+    message("Untar complete")
+  }
 }
 
 
-
 #' load_SL_tibble
 #'
 #' Import a chosen StudentLife table as
 #' a tibble. Leave \code{schema} and \code{table}
 #' unspecified to choose interactively via a
-#' menu.
+#' menu. This function is only intended for use
+#' with the studentlife dataset in it's original
+#' format, with the original directory structure.
+#' See the examples below for the recommended alternative approach
+#' to loading tables when the RData format is used.
 #'
 #' @param schema A character string. The menu 1 choice. Leave
 #' blank to choose interactively.
@@ -125,11 +157,32 @@ download_studentlife <- function(
 #' \code{dateonly_SL_tibble} (which are all
 #' subclasses of \code{SL_tibble}).
 #'
-#' @examples
+#'@examples
+#'## Example that uses RData format to efficiently
+#'## download and load tables, as an alternative
+#'## to using this function.
+#'\dontrun{
+#' d <- tempdir()
+#' download_studentlife(location = d, url = "rdata")
+#'
+#' # Choose the schema and table from the list SL_tables:
+#' SL_tables
+#'
+#' # Example with activity table from sensing schema
+#' schema <- "sensing"
+#' table <- "activity"
+#' act <- readRDS(paste0(d, "/dataset_rds/", schema, "/", table, ".Rds"))
+#' act
+#'}
+#'
+#'## Example that uses the studentlife dataset in
+#'## its original format.
+#'
+#'# Use url = "dartmouth" for the full original dataset
 #'d <- tempdir()
 #'download_studentlife(location = d, url = "testdata")
 #'
-#'\donttest{
+#'\dontrun{
 #'## With menu
 #'load_SL_tibble(location = d)
 #'}
@@ -142,7 +195,7 @@ download_studentlife <- function(
 #'act <- load_SL_tibble(schema = "sensing", table = "activity",
 #'                      location = d, csv_nrows = 10)
 #'
-#'\donttest{
+#'\dontrun{
 #'## Browse all tables with timestamps (non-interval)
 #'load_SL_tibble(location = d, time_options = "timestamp")
 #'
@@ -176,8 +229,16 @@ load_SL_tibble <- function(
   }
 
   if ( missing(schema) & !missing(table) ) {
-    stop(paste0("if table is specified then schema ",
-                "must be specified also"))
+
+    guess_schema <- names(
+      unlist(lapply(studentlife::SL_tables, function(x){which(x == table)})))
+    if (length(guess_schema) != 1) {
+      stop(paste0("Had trouble determining the schema, ",
+                  "try specifying it with the schema argument"))
+    } else {
+      schema <- guess_schema
+    }
+
   }
 
   if (!missing(schema))
@@ -214,6 +275,10 @@ load_SL_tibble <- function(
     tab, schema = attr(path, "schema"),
     table = attr(path, "table"))
 
+  if ( attr(tab, "table") == "PAM" && ("picture_idx" %in% names(tab)) ) {
+    tab <- PAM_categorise(tab, pam_name = "picture_idx")
+  }
+
   names(tab) <- clean_strings(names(tab))
 
   return(tab)
@@ -316,7 +381,8 @@ get_txt_tab <- function(path, location, vars) {
   if ( "date-time" %in% names(tab) ) {
     names(tab)[pmatch("date-time", names(tab))] <- "timestamp"
     tab$timestamp <- as.numeric(
-      as.POSIXct(tab$timestamp, origin="1970-01-01"))
+      as.POSIXct(tab$timestamp, origin="1970-01-01",
+                 tz = getOption("SL_timezone")))
     class(tab) <- c("timestamp_SL_tbl", class(tab))
   }
 
@@ -351,7 +417,9 @@ get_wide_csv_tab <- function(path, location, vars, csv_nrows) {
 
     tab <- tidyr::gather(tab, "date", "deadlines", -c("uid"))
     tab$date <- as.Date(
-      as.POSIXct(substr(tab$date,2,11), format = "%Y.%m.%d"))
+      as.POSIXct(substr(tab$date,2,11), format = "%Y.%m.%d",
+                 tz = getOption("SL_timezone")),
+      tz = getOption("SL_timezone"))
 
     class(tab) <- c("SL_tbl", class(tab))
 
